@@ -1,27 +1,13 @@
 wysihtml5.lang.Dispatcher = Base.extend(
   /** @scope wysihtml5.lang.Dialog.prototype */ {
-  observe: function(eventName, handler) {
+  on: function(eventName, handler) {
     this.events = this.events || {};
     this.events[eventName] = this.events[eventName] || [];
     this.events[eventName].push(handler);
     return this;
   },
 
-  on: function() {
-    return this.observe.apply(this, wysihtml5.lang.array(arguments).get());
-  },
-
-  fire: function(eventName, payload) {
-    this.events = this.events || {};
-    var handlers = this.events[eventName] || [],
-        i        = 0;
-    for (; i<handlers.length; i++) {
-      handlers[i].call(this, payload);
-    }
-    return this;
-  },
-
-  stopObserving: function(eventName, handler) {
+  off: function(eventName, handler) {
     this.events = this.events || {};
     var i = 0,
         handlers,
@@ -40,5 +26,25 @@ wysihtml5.lang.Dispatcher = Base.extend(
       this.events = {};
     }
     return this;
+  },
+  
+  fire: function(eventName, payload) {
+    this.events = this.events || {};
+    var handlers = this.events[eventName] || [],
+        i        = 0;
+    for (; i<handlers.length; i++) {
+      handlers[i].call(this, payload);
+    }
+    return this;
+  },
+  
+  // deprecated, use .on()
+  observe: function() {
+    return this.on.apply(this, arguments);
+  },
+  
+  // deprecated, use .off()
+  stopObserving: function() {
+    return this.off.apply(this, arguments);
   }
 });
\ No newline at end of file
